=============
Miscellaneous
=============

.. currentmodule:: polars
.. autosummary::
   :toctree: api/

    Series.equals
    Series.map_elements
    Series.reinterpret
    Series.set_sorted
    Series.to_physical
    Series.get_chunks
